@@ -153,7 +153,7 @@ class LeanConfigManager:
 
         config["composer-dll-directory"] = "."
 
-        config["debugging"] = debugging_method is not None
+        config["debugging"] = debugging_method is not None and debugging_method != DebuggingMethod.Mono
         config["debugging-method"] = debugging_method.value if debugging_method is not None else "LocalCmdline"
 
         config["job-user-id"] = self._cli_config_manager.user_id.get_value(default="0")
